@@ -61,4 +61,21 @@ sub multiply_by_matrix {
 
 	return $retm;
 }
+
+sub determinant {
+	my $self = shift;
+
+	my $det = 0;
+
+	for (my $i = 0; $i < $self->{n}; $i++) {
+		my $val = 0;
+		for (my $j = 0; $j < $self->{m}; $j++) {
+			my $k = 0;
+			$val = $val + $self->{mat}[$j][$i + $k++]  
+		}
+		$det += $val;	
+	}
+
+	return $det;
+}	
 1;
